---
title: Installation
icon: arrow-down-to-line
---

## Install FastAPI-MCP

We recommend using [uv](https://docs.astral.sh/uv/), a fast Python package installer:

```bash
uv add fastapi-mcp
```

Alternatively, you can install with `pip` or `uv pip`:

<CodeGroup>
    ```bash uv
    uv pip install fastapi-mcp
    ```

    ```bash pip
    pip install fastapi-mcp
    ```
</CodeGroup>
